@@ -14,7 +14,10 @@ service = import_module(f"akerbp.mlops.services.{service_name}").service
 
 def handle(data, secrets, function_call_info):
    try:
-      output = service(data, secrets)
+      if data:
+         output = service(data, secrets)
+      else:
+         output = {}
       cdf.api_keys = secrets
       cdf.set_up_cdf_client(context='deploy')
       metadata = cdf.get_function_metadata(function_call_info["function_id"])
