@@ -10,6 +10,7 @@ import sys
 import os 
 import json
 import functools
+from datetime import datetime
 from shutil import make_archive, unpack_archive
 
 from cognite.client.exceptions import CogniteNotFoundError, CogniteAPIError
@@ -92,6 +93,8 @@ def create_function_from_folder(
       - function_name: name of the function to create
       - folder: path where the source code is located
       - handler_path: path to the handler file
+      - description: (string) function documentation
+      - owner: (string) the function's owner's email
       - secrets: api keys or similar that should be passed to the function
     """
     client = global_client["functions"]
@@ -121,8 +124,8 @@ def create_function_from_folder(
 def create_function_from_file(
     function_name, 
     file_id, 
-    owner,
     description,
+    owner,
     secrets={}
 ):
     """
@@ -131,7 +134,8 @@ def create_function_from_file(
 
     Inputs:
       - function_name: (string) name of the function to create
-      - file_id: (string) the id for the function file in CDF Files
+      - file_id: (int) the id for the function file in CDF Files
+      - description: (string) function documentation
       - owner: (string) the function's owner's email
       - secrets: (optional) api keys or similar that should be passed to the
         function
@@ -218,7 +222,7 @@ def redeploy_function(
 
     Inputs:
       - function_name: name of the function to create
-      - file_id: (string) the id for the function file in CDF Files
+      - file_id: (int) the id for the function file in CDF Files
       - owner: (string) the function's owner's email
       - secrets: (optional) api keys or similar that should be passed to the
         function
@@ -235,23 +239,39 @@ def redeploy_function(
 
 
 def get_function_metadata(function_id):
-   
-   client = global_client["functions"]
-   function = client.functions.retrieve(id=function_id)
-   metadata = dict(
-      external_id=function.external_id,
-      description=function.description,
-      owner=function.owner,
-      status=function.status,
-      file_id=function.file_id,
-      created_time=function.created_time
-   )
-   return metadata
+    """
+    Generate metadata for a function
+    Input:
+        - function_id: (int) function's id in CDF
+    Output:
+        - (dictionary) function's metadata
+    """
+    client = global_client["functions"]
+    function = client.functions.retrieve(id=function_id)
+
+    ts = function.created_time/1000
+    created_time = datetime.utcfromtimestamp(ts).strftime('%Y-%m-%d %H:%M:%S')
+
+    metadata = dict(
+        external_id=function.external_id,
+        description=function.description,
+        owner=function.owner,
+        status=function.status,
+        file_id=function.file_id,
+        created_time=created_time
+    )
+    return metadata
 
 
 def call_function(function_name, data):
     """
     Call a function deployed in CDF
+
+    Input:
+        - function_name: (string) function's external id in CDF
+        - data: (dictionary) data for the call
+    Output:
+        - (dictionary) function's response
     """
     client = global_client["functions"]
     function = client.functions.retrieve(external_id=function_name)
