@@ -6,6 +6,7 @@ Model registry uses CDF Files.
 """ 
 import os
 import traceback
+from multiprocessing import Process
 from pathlib import Path
 
 import akerbp.mlops.model_manager as mm
@@ -86,7 +87,9 @@ def deploy(project_settings):
         
     for c in project_settings:
         try:
-            deploy_model(c)
+            p = Process(target=deploy_model, args=(c,)) 
+            p.start()
+            p.join()
         except Exception:
             trace = traceback.format_exc()
             message = f"Model failed to deploy!\n{trace}"
