@@ -52,7 +52,8 @@ def to_folder(path, folder_path):
     Input:
       - path: supported formats
             - file/folder path (Path): e,g, Path("my/folder")
-            - module file (tuple/list): e.g. ("my.module", "my_file"). Module path has to be a string, but file name can be a Path object. 
+            - module file (tuple/list): e.g. ("my.module", "my_file"). Module
+            path has to be a string, but file name can be a Path object. 
     """
     if isinstance(path, (tuple,list) ):
         module_path, file = path
