@@ -1,6 +1,6 @@
 # model_manager.py
 
-import os
+from pathlib import Path
 
 import akerbp.mlops.cdf.helpers as cdf
 from akerbp.mlops.core import config, logger
@@ -22,7 +22,7 @@ def setup(cdf_api_keys=None):
     cdf.set_up_cdf_client()
 
 
-def upload_new_model_version(model_name, env, folder, metadata):
+def upload_new_model_version(model_name, env, folder, metadata={}):
     """
     Upload a new model version. Files in a folder are archived and stored 
     with external id `model_name/env/version`, where version is automatically
@@ -31,20 +31,23 @@ def upload_new_model_version(model_name, env, folder, metadata):
     Input:
         -model_name: name of the model 
         -env: name of the environment ('dev', 'test', 'prod')
-        -folder: path to folder whose content will be uploaded
+        -folder: (Path) path to folder whose content will be uploaded
         -metadata: dictionary with metadata (it should not contain a 'version'
         key)
     
     Output:
         - model metadata (dictionary)
     """
-
     file_list = cdf.query_file_versions(
         external_id_prefix= f"{model_name}/{env}/", 
         directory_prefix='/mlops', 
         uploaded=None # count any file
     )
-    latest_v = file_list.metadata.apply(lambda d:int(d["version"])).max()
+    if not file_list.empty:
+        latest_v = file_list.metadata.apply(lambda d:int(d["version"])).max()
+    else:
+        latest_v = 0
+    
     version = int(latest_v) + 1 # int64 isn't json-serializable
     if "version" in metadata:
         logging.error(
@@ -54,6 +57,9 @@ def upload_new_model_version(model_name, env, folder, metadata):
     metadata["version"] = version
     external_id = f"{model_name}/{env}/{version}"
 
+    if not isinstance(folder, Path):
+        folder = Path(folder)
+    
     folder_info = cdf.upload_folder(
         external_id, 
         folder, 
